# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""fixing ingest_cal script

Revision ID: 34d7311d8290
Revises: c857908b6acb
Create Date: 2021-07-21 14:06:23.987647

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "34d7311d8290"
down_revision = "c857908b6acb"
branch_labels = None
depends_on = None

script_content = """#!/bin/sh
set -o errexit

./conveyor --retrieve $1
./ingest_envoy --calibration $1

"""

condor = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

"""


old_script = """#!/bin/sh
set -o errexit

./conveyor --retrieve $1
./ingest_envoy --ingest-cal $1

"""

restore_metadata = """{
    "fileSetIds": ["{{sdmId}}", "{{calSdmId}}"],
    "workflowName": "restore_cms",
    "systemId": "{{request_id}}",
    "creationTime": "{{created_at}}",
    "productLocator": "{{product_locator}}",
    "calProductLocator": "{{cal_locator}}",
    "projectMetadata": {
        "projectCode": "{{projectCode}}",
        "title": "{{title}}",
        "telescope": "{{telescope}}",
        "startTime": "{{startTime}}",
        "observer": "{{observer}}"
      },
    "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""

cal_metadata = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "telescope": "{{telescope}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""

cms_metadata = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "telescope": "{{telescope}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

"""


old_condor = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

"""

old_restore_metadata = """{
    "fileSetIds": ["{{sdmId}}", "{{calSdmId}}"],
    "workflowName": "restore_cms",
    "systemId": "{{request_id}}",
    "creationTime": "{{created_at}}",
    "productLocator": "{{product_locator}}",
    "calProductLocator": "{{cal_locator}}",
    "projectMetadata": {
        "projectCode": "{{projectCode}}",
        "title": "{{title}}",
        "startTime": "{{startTime}}",
        "observer": "{{observer}}"
      },
    "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""

old_cal_metadata = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}

"""

old_cms_metadata = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
      "projectCode": "{{projectCode}}",
      "title": "{{title}}",
      "startTime": "{{startTime}}",
      "observer": "{{observer}}"
    },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{script_content}' WHERE filename='ingest_cal.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor}' WHERE filename='ingest_cal.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_metadata}' WHERE filename='metadata.json' AND workflow_name='restore_cms'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cal_metadata}' WHERE filename='metadata.json' AND workflow_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{cms_metadata}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_script}' WHERE filename='ingest_cal.sh'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_metadata}' WHERE filename='metadata.json' AND workflow_name='restore_cms'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_cal_metadata}' WHERE filename='metadata.json' AND workflow_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_cms_metadata}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
        """
    )
